aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/release_contrib.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/release_contrib.py29
1 files changed, 13 insertions, 16 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/release_contrib.py b/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
index 01b464ac..f2de29df 100644
--- a/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
+++ b/python_openapi_client/fatcat_openapi_client/models/release_contrib.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,23 +16,22 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.creator_entity import CreatorEntity # noqa: F401,E501
-
class ReleaseContrib(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'index': 'int',
'creator_id': 'str',
'creator': 'CreatorEntity',
@@ -41,7 +40,7 @@ class ReleaseContrib(object):
'surname': 'str',
'role': 'str',
'raw_affiliation': 'str',
- 'extra': 'object'
+ 'extra': 'dict(str, object)'
}
attribute_map = {
@@ -57,7 +56,7 @@ class ReleaseContrib(object):
}
def __init__(self, index=None, creator_id=None, creator=None, raw_name=None, given_name=None, surname=None, role=None, raw_affiliation=None, extra=None): # noqa: E501
- """ReleaseContrib - a model defined in Swagger""" # noqa: E501
+ """ReleaseContrib - a model defined in OpenAPI""" # noqa: E501
self._index = None
self._creator_id = None
@@ -136,8 +135,8 @@ class ReleaseContrib(object):
raise ValueError("Invalid value for `creator_id`, length must be less than or equal to `26`") # noqa: E501
if creator_id is not None and len(creator_id) < 26:
raise ValueError("Invalid value for `creator_id`, length must be greater than or equal to `26`") # noqa: E501
- if creator_id is not None and not re.search('[a-zA-Z2-7]{26}', creator_id): # noqa: E501
- raise ValueError("Invalid value for `creator_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if creator_id is not None and not re.search(r'[a-zA-Z2-7]{26}', creator_id): # noqa: E501
+ raise ValueError(r"Invalid value for `creator_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._creator_id = creator_id
@@ -145,7 +144,6 @@ class ReleaseContrib(object):
def creator(self):
"""Gets the creator of this ReleaseContrib. # noqa: E501
- Complete creator entity. Only returned in GET responses, and only if `contribs` included in the `expand` query parameter. # noqa: E501
:return: The creator of this ReleaseContrib. # noqa: E501
:rtype: CreatorEntity
@@ -156,7 +154,6 @@ class ReleaseContrib(object):
def creator(self, creator):
"""Sets the creator of this ReleaseContrib.
- Complete creator entity. Only returned in GET responses, and only if `contribs` included in the `expand` query parameter. # noqa: E501
:param creator: The creator of this ReleaseContrib. # noqa: E501
:type: CreatorEntity
@@ -286,7 +283,7 @@ class ReleaseContrib(object):
Additional free-form JSON metadata about this contributor/contribution. See guide for normative schema. # noqa: E501
:return: The extra of this ReleaseContrib. # noqa: E501
- :rtype: object
+ :rtype: dict(str, object)
"""
return self._extra
@@ -297,7 +294,7 @@ class ReleaseContrib(object):
Additional free-form JSON metadata about this contributor/contribution. See guide for normative schema. # noqa: E501
:param extra: The extra of this ReleaseContrib. # noqa: E501
- :type: object
+ :type: dict(str, object)
"""
self._extra = extra
@@ -306,7 +303,7 @@ class ReleaseContrib(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,23 +16,22 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name